babl r331 - in trunk: . babl docs



Author: ok
Date: Thu Jun 12 21:43:55 2008
New Revision: 331
URL: http://svn.gnome.org/viewvc/babl?rev=331&view=rev

Log:
* babl/babl-fish-path.c: (legal_error): s/BABL_TOLERANCE/
* docs/index-static.html.in: s/BABL_ACCURACY/BABL_TOLERANCE/


Modified:
   trunk/ChangeLog
   trunk/babl/babl-fish-path.c
   trunk/docs/index-static.html.in

Modified: trunk/babl/babl-fish-path.c
==============================================================================
--- trunk/docs/index-static.html.in	(original)
+++ trunk/docs/index-static.html.in	Thu Jun 12 21:43:55 2008
@@ -265,7 +265,7 @@
 </pre>
 -->
 
-    <p>Through the environment variable <em>BABL_ACCURACY</em> you can control
+    <p>Through the environment variable <em>BABL_TOLERANCE</em> you can control
     a speed/performance trade off that by default is set very low (0.000001)
     values in the range 0.01-0.1 can provide reasonable preview performance
     by allowing lower numerical accuracy</p>.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/babl/babl-fish-path.c	(original)
+++ trunk/babl/babl-fish-path.c	Thu Jun 12 21:43:55 2008
@@ -67,7 +67,7 @@
   if (error != 0.0)
     return error;
 
-  env = getenv ("BABL_ACCURACY");
+  env = getenv ("BABL_TOLERANCE");
   if (env)
     error = atof (env);
   else
@@ -100,7 +100,7 @@
  * the shortest path in a graph where formats are the vertices
  * and conversions are the edges. However, there is an additional
  * constraint to the shortest path, that limits conversion error
  * introduced by such a path to be less than BABL_ACCURACY. This
  * prohibits usage of any reasonable shortest path construction
  * algorithm such as Dijkstra's algorithm. The shortest path is
  * constructed by enumerating all available paths that are less
@@ -100,7 +100,7 @@
  * and conversions are the edges. However, there is an additional
  * constraint to the shortest path, that limits conversion error
- * introduced by such a path to be less than BABL_ACCURACY. This
+ * introduced by such a path to be less than BABL_TOLERANCE. This
  * prohibits usage of any reasonable shortest path construction
  * algorithm such as Dijkstra's algorithm. The shortest path is

Modified: trunk/docs/index-static.html.in
==============================================================================